<?php

declare(strict_types = 1);

namespace M_Besteck\CookieQuestion\EM;

/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

use TYPO3\CMS\Core\Utility\GeneralUtility;

/**
 * @author mbesteck
 */
class CQConfig
{

    /**
     *
     * @var array Keeps the present Cookie Question theme names.
     */
    protected $presentThemes = array();

    /**
     * @return string
     */
    public function getThemeSelectBoxDesktop(array $params, $configurationForm)
    {
        return $this->getThemeSelectBox($params, 'Desktop');
    }

    /**
     * @return string
     */
    public function getThemeSelectBoxTablet(array $params, $configurationForm)
    {
        return $this->getThemeSelectBox($params, 'Tablet');
    }

    /**
     * @return string
     */
    public function getThemeSelectBoxPhone(array $params, $configurationForm)
    {
        return $this->getThemeSelectBox($params, 'Phone');
    }

    /**
     * Detects the present CookieQuestion themes and stores their names in
     * presentThemes.
     */
    protected function setupPresentThemes()
    {
        if (empty($this->presentThemes)) {
            $themesDir = GeneralUtility::getFileAbsFileName('EXT:cookie_question/Resources/Public/cookieQuestion/themes');
            $dirHandle = opendir($themesDir);
            if ($dirHandle !== FALSE) {
                $fileName = FALSE;
                do {
                    $fileName = readdir($dirHandle);
                    if (($fileName !== FALSE) &&
                            (strpos($fileName, 'CookieQuestionTheme_') === 0) &&
                            (substr($fileName, -3) === '.js')) {
                        $this->presentThemes[] = substr($fileName, 20, strpos($fileName, '.') - strlen($fileName));
                    }
                } while ($fileName !== FALSE);
                closedir($dirHandle);
                $this->presentThemes = array_unique($this->presentThemes);
                sort($this->presentThemes);
            }
        }
    }

    /**
     * Assembles the HTML code for a select box.
     * @return string
     */
    protected function getThemeSelectBox(array $params, $deviceType)
    {
        $this->setupPresentThemes();
        $actualTheme = $params['fieldValue'];
        $fieldId = str_replace(array('[', ']'), '_', $params['fieldName']);
        $content = array();
        $content[] = '<input type="hidden" id="' . $fieldId
                . '" name="' . $params['fieldName'] . '" value="' . $actualTheme . '" />';
        $content[] = '<select id="cookieQuestionSelectedTheme' . $deviceType . '" onchange="setCookieQuestionTheme' . $deviceType . '()">';
        foreach ($this->presentThemes as $theme) {
            $content[] = '<option' . (($theme == $actualTheme) ? ' selected' : '') . '>' . $theme . '</option>';
        }
        $content[] = '</select>';
        $content[] = '<script type="text/javascript">';
        $content[] = 'function setCookieQuestionTheme' . $deviceType . '() {';
        $content[] = 'var cqSelectElem = document.getElementById("cookieQuestionSelectedTheme' . $deviceType . '");';
        $content[] = 'var cqSelected = cqSelectElem.options[cqSelectElem.selectedIndex].text;';
        $content[] = 'document.getElementById("' . $fieldId . '").value = cqSelected;';
        $content[] = '}';
        $content[] = '</script>';
        return implode(PHP_EOL, $content);
    }

}
