<?php

declare(strict_types = 1);

/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

namespace M_Besteck\CookieQuestion\Util;

use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Core\Utility\PathUtility;

/**
 * Provides a function to insert the CookieQuestion code into the page.
 * 
 * @author mbesteck
 */
class CookieQuestionHandler
{
    const CQ_DEVICE_KEY = 'cookieQuestionDevice';

    /**
     * Inserts the CookieQuestion inclusion code into $reference->content
     * 
     * @param type $params
     * @param type $reference
     */
    public function insertCookieQuestion(&$params, &$reference)
    {
        $devType = $GLOBALS['TSFE']->fe_user->getKey('ses', self::CQ_DEVICE_KEY);
        if (empty($devType)) {
            require_once 'Mobile_Detect.php';
            $mobileDetect = new Mobile_Detect();
            $devType = $mobileDetect->isTablet() ? 'tablet' : ($mobileDetect->isMobile() ? 'phone' : 'desktop');
            $GLOBALS['TSFE']->fe_user->setKey('ses', self::CQ_DEVICE_KEY, $devType);
        }
        $extensionConfiguration = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf']['cookie_question']);
        $actualTheme = $extensionConfiguration['theme_' . $devType];
        $cqFile = GeneralUtility::getFileAbsFileName('EXT:cookie_question/Resources/Public/cookieQuestion/cookieQuestionStarter.js');
        $cqFile = PathUtility::getRelativePathTo($cqFile);
        $cqFile = rtrim($cqFile, '/');
        $cqFile = PathUtility::getAbsoluteWebPath($cqFile);
        $include = '<script src="' . $cqFile . '" data-theme="' . $actualTheme . '" type="text/javascript"></script>';
        $bodyEndPos = strrpos($reference->content, '</body>');
        $reference->content = substr($reference->content, 0, $bodyEndPos)
                . $include
                . substr($reference->content, $bodyEndPos);
    }
}
